@@ -40,7 +40,7 @@ check_part (SoupMessageHeaders *headers, const char *body, gsize body_len,
 	goffset start, end, total_length;
 
 	debug_printf (1, "    Content-Range: %s\n",
-		      soup_message_headers_get (headers, "Content-Range"));
+		      soup_message_headers_get_one (headers, "Content-Range"));
 
 	if (!soup_message_headers_get_content_range (headers, &start, &end, &total_length)) {
 		debug_printf (1, "    Could not find/parse Content-Range\n");
@@ -91,7 +91,7 @@ do_single_range (SoupSession *session, SoupMessage *msg,
 	const char *content_type;
 
 	debug_printf (1, "    Range: %s\n",
-		      soup_message_headers_get (msg->request_headers, "Range"));
+		      soup_message_headers_get_one (msg->request_headers, "Range"));
 
 	soup_session_send_message (session, msg);
 
@@ -137,7 +137,7 @@ do_multi_range (SoupSession *session, SoupMessage *msg,
 	int i, length;
 
 	debug_printf (1, "    Range: %s\n",
-		      soup_message_headers_get (msg->request_headers, "Range"));
+		      soup_message_headers_get_one (msg->request_headers, "Range"));
 
 	soup_session_send_message (session, msg);
 
@@ -356,12 +356,12 @@ main (int argc, char **argv)
 	session = soup_test_session_new (SOUP_TYPE_SESSION_ASYNC, NULL);
 
 	debug_printf (1, "1. Testing against apache\n");
-	do_range_test (session, "http://localhost:47524/", FALSE);
+	do_range_test (session, "http://127.0.0.1:47524/", FALSE);
 
 	debug_printf (1, "\n2. Testing against SoupServer\n");
 	server = soup_test_server_new (FALSE);
 	soup_server_add_handler (server, NULL, server_handler, NULL, NULL);
-	base_uri = g_strdup_printf ("http://localhost:%u/",
+	base_uri = g_strdup_printf ("http://127.0.0.1:%u/",
 				    soup_server_get_port (server));
 	do_range_test (session, base_uri, TRUE);
 	g_free (base_uri);
